@@ -58,6 +58,8 @@ single.meanvar.poisson<-function(data,penalty="SIC",pen.value=0,class=TRUE,param
   
   if(is.null(dim(data))==TRUE){
     n=length(data)
+    if(n<4){stop('Data must have atleast 4 observations to fit a changepoint model.')}
+    
     if(penalty=="Asymptotic"){
       return('Asymptotic penalties for the Poisson test statistic are not available yet, please choose an alternative penalty type')
     }
@@ -77,6 +79,8 @@ single.meanvar.poisson<-function(data,penalty="SIC",pen.value=0,class=TRUE,param
   }
   else{ 
     n=ncol(data)
+    if(n<4){stop('Data must have atleast 4 observations to fit a changepoint model.')}
+    
     if(penalty=="Asymptotic"){
       return('Asymptotic penalties for the Poisson test statistic are not available yet, please choose an alternative penalty type')
     }
@@ -108,6 +112,8 @@ PELT.meanvar.poisson=function(data,pen=0){
   if((sum(data<0)>0)){stop('Poisson test statistic requires positive data')}
   if(sum(as.integer(data)==data)!=length(data)){stop('Poisson test statistic requires integer data')}
   n=length(data)
+  if(n<4){stop('Data must have atleast 4 observations to fit a changepoint model.')}
+  
   y=c(0,cumsum(data))
   error=0
   
@@ -132,7 +138,8 @@ segneigh.meanvar.poisson=function(data,Q=5,pen=0){
   if((sum(data<0)>0)){stop('Poisson test statistic requires positive data')}
   if(sum(as.integer(data)==data)!=length(data)){stop('Poisson test statistic requires integer data')}
   n=length(data)
-  if(Q>(n/2)){stop(paste('Q is larger than the maximum number of segments',n/2))}
+  if(n<4){stop('Data must have atleast 4 observations to fit a changepoint model.')}
+  if(Q>((n/2)+1)){stop(paste('Q is larger than the maximum number of segments',(n/2)+1))}
   all.seg=matrix(0,ncol=n,nrow=n)
   for(i in 1:n){
     sumx=0
@@ -189,7 +196,8 @@ binseg.meanvar.poisson=function(data,Q=5,pen=0){
   if(sum(as.integer(data)==data)!=length(data)){stop('Poisson test statistic requires integer data')}
   
   n=length(data)
-  if(Q>(n/2)){stop(paste('Q is larger than the maximum number of segments',n/2))}
+  if(n<4){stop('Data must have atleast 4 observations to fit a changepoint model.')}
+  if(Q>((n/2)+1)){stop(paste('Q is larger than the maximum number of segments',(n/2)+1))}
   y=c(0,cumsum(data))
   
   storage.mode(y)='double'
